# Reporting Security Issues

The Nebius team take security bugs seriously. We appreciate your efforts to responsibly disclose your findings, and 
will make every effort to acknowledge your contributions.

To report a security issue, please use the GitHub Security Advisory 
["Report a Vulnerability"](https://github.com/nebius/contree-mcp/security/advisories/new) tab.

The Nebius team will send a response indicating the next steps in handling your report. After the initial reply to your
report, the Nebius team will keep you informed of the progress towards a fix and full announcement, and may ask for
additional information or guidance.

## Learning More About Security in Nebius

To learn more about security in Nebius, please see [this page](https://nebius.ai/docs/security).
